@@ -1,6 +1,6 @@
 from lightning import Lightning, Session, Visualization
 from random import randrange, uniform
-from numpy import random, ceil, array
+from numpy import random, ceil, array, clip
 
 
 lightning = Lightning()
@@ -31,11 +31,11 @@ class TestLightningAPIClient:
 
         x = random.randn(100)
         y = random.randn(100)
-        c = ceil(random.rand(100)*10)
+        l = ceil(random.rand(100) * 5)
+        s = random.rand(100) * 10 + 10
+        a = clip(random.rand(100) + 0.1, 0, 1)
 
-        viz = lightning.scatter(x, y, clrs=c)
-
-        print(viz)
+        viz = lightning.scatter(x, y, label=l, size=s, alpha=a)
 
         assert isinstance(viz, Visualization)
         assert hasattr(viz, 'id')
@@ -43,18 +43,28 @@ class TestLightningAPIClient:
 
     def test_create_line(self):
 
-        x = random.randn(100)
+        series = random.randn(5,100)
+        s = random.rand(5) * 5 + 5
 
-        viz = lightning.line(x)
+        viz = lightning.line(series, size=4)
 
         assert isinstance(viz, Visualization)
         assert hasattr(viz, 'id')
 
 
-    def test_create_image(self):
+    def test_create_images(self):
 
-        img1 = random.rand(256, 256, 3)
-        img2 = random.rand(256, 256, 3)
+        img1 = random.rand(128, 256, 3)
+
+        viz = lightning.image(img1)
+
+        assert isinstance(viz, Visualization)
+        assert hasattr(viz, 'id')
+
+    def test_create_gallery(self):
+
+        img1 = random.rand(128, 256, 3)
+        img2 = random.rand(128, 256, 3)
 
         viz = lightning.gallery([img1, img2])
 
@@ -62,26 +72,27 @@ class TestLightningAPIClient:
         assert hasattr(viz, 'id')
 
 
-    def test_create_roi(self):        
+    def test_create_scatter_line(self):        
 
         x = random.randn(50)
         y = random.randn(50)
-        timeseries = random.randn(50,1000)
+        series = random.randn(50,1000)
+        l = ceil(random.rand(50) * 5)
 
-        viz = lightning.roi(x, y, timeseries)
+        viz = lightning.scatterline(x, y, series, label=l)
 
         assert isinstance(viz, Visualization)
         assert hasattr(viz, 'id')
 
 
-    def test_create_line_stacked(self):
+    # def test_create_line_stacked(self):
 
-        timeseries = random.randn(6, 100)
+    #     series = random.randn(6, 100)
 
-        viz = lightning.linestacked(timeseries)
+    #     viz = lightning.linestacked(series)
 
-        assert isinstance(viz, Visualization)
-        assert hasattr(viz, 'id')
+    #     assert isinstance(viz, Visualization)
+    #     assert hasattr(viz, 'id')
 
 
     def test_ipython_support(self):
@@ -98,9 +109,9 @@ class TestLightningAPIClient:
     def test_create_us_map(self):
 
         states = ["NA", "AK", "AL", "AR", "AZ", "CA", "CO","CT","DC","DE","FL","GA","HI","IA","ID","IL","IN","KS","KY","LA","MA","MD","ME","MI","MN","MO","MS","MT","NC","ND","NE","NH","NJ","NM","NV","NY","OH","OK","OR","PA","RI","SC","SD","TN","TX","UT","VA","VI","VT","WA","WI","WV","WY"]
-        mapDict = dict((state, random.random()) for state in states)
+        values = random.randn(len(states))
 
-        viz = lightning.plot(type='map', data=mapDict)
+        viz = lightning.map(states,values, colormap="Blues")
 
         assert isinstance(viz, Visualization)
         assert hasattr(viz, 'id')
@@ -108,13 +119,23 @@ class TestLightningAPIClient:
     def test_create_world_map(self):
 
         countries = ["USA", "MEX", "CAN", "GER", "AUS", "BRA", "ARG", "PER", "SPA", "POR", "FRA", "ITA", "RUS", "CHN", "IND"]
-        mapDict = dict((country, random.random()) for country in countries)
+        values = random.randn(len(countries))
 
-        viz = lightning.plot(type='map', data=mapDict)
+        viz = lightning.map(countries, values, colormap="Purples")
 
         assert isinstance(viz, Visualization)
         assert hasattr(viz, 'id')
 
+    def test_create_adjacency(self):
+
+        mat = random.randn(10,10)
+        mat[mat<0.8] = 0
+        l = ceil(random.rand(10)*4)
+
+        viz = lightning.adjacency(mat, label=l)
+
+        assert isinstance(viz, Visualization)
+        assert hasattr(viz, 'id')
 
     def test_create_matrix(self):
 
@@ -124,10 +145,9 @@ class TestLightningAPIClient:
         assert isinstance(viz, Visualization)
         assert hasattr(viz, 'id')
 
-
     def test_create_force(self):
 
-        mat = array([[random.uniform(0, 15) if random.random() > 0.8 else 0 for _ in xrange(15)] for _ in xrange(15)])
+        mat = array([[random.uniform(0, 25) if random.random() > 0.95 else 0 for _ in xrange(25)] for _ in xrange(25)])
         viz = lightning.force(mat)
 
         assert isinstance(viz, Visualization)
@@ -135,11 +155,11 @@ class TestLightningAPIClient:
 
     def test_create_graph(self):
 
-        mat = array([[random.uniform(0, 15) if random.random() > 0.8 else 0 for _ in xrange(15)] for _ in xrange(15)])
-        x = random.randn(15)
-        y = random.randn(15)
+        mat = array([[random.uniform(0, 25) if random.random() > 0.9 else 0 for _ in xrange(25)] for _ in xrange(25)])
+        x = random.randn(25)
+        y = random.randn(25)
         
-        viz = lightning.graph(mat, x, y)
+        viz = lightning.graph(x, y, mat)
 
         assert isinstance(viz, Visualization)
         assert hasattr(viz, 'id')
